==> tomcat10-slf4j-logback-10.1.15-sources.jar: org/apache/juli/logging/ch/qos/logback/core/joran/JoranConstants.java <==
/**
 * Logback: the reliable, generic, fast and flexible logging framework.
 * Copyright (C) 1999-2015, QOS.ch. All rights reserved.
 *
 * This program and the accompanying materials are dual-licensed under
 * either the terms of the Eclipse Public License v1.0 as published by
 * the Eclipse Foundation
 *
 *   or (per the licensee's choosing)
 *
 * under the terms of the GNU Lesser General Public License version 2.1
 * as published by the Free Software Foundation.
 */
package org.apache.juli.logging.ch.qos.logback.core.joran;

/**
 *
 * This class contains constants used by Joran components.
 * 
 * @author Ceki G&uuml;lc&uuml;
 *
 */
public abstract class JoranConstants {
    public static final String INCLUDED_TAG = "included";
    public static final String INCLUDE_TAG = "include";

    public static final String APPENDER_TAG = "appender";
    public static final String REF_ATTRIBUTE = "ref";
    public static final String ADDITIVITY_ATTRIBUTE = "additivity";
    public static final String LEVEL_ATTRIBUTE = "level";
    public static final String CONVERTER_CLASS_ATTRIBUTE = "converterClass";
    public static final String CONVERSION_WORD_ATTRIBUTE = "conversionWord";
    public static final String PATTERN_ATTRIBUTE = "pattern";
    public static final String VALUE_ATTR = "value";
    public static final String ACTION_CLASS_ATTRIBUTE = "actionClass";

    public static final String INHERITED = "INHERITED";
    public static final String NULL = "NULL";
    static final Class<?>[] ONE_STRING_PARAM = new Class[] { String.class };

    public static final String APPENDER_BAG = "APPENDER_BAG";
    public static final String APPENDER_REF_BAG = "APPENDER_REF_BAG";
    // public static final String FILTER_CHAIN_BAG = "FILTER_CHAIN_BAG";
}

==> tomcat10-slf4j-logback-10.1.48-sources.jar: org/apache/juli/logging/ch/qos/logback/core/joran/JoranConstants.java <==
/**
 * Logback: the reliable, generic, fast and flexible logging framework.
 * Copyright (C) 1999-2015, QOS.ch. All rights reserved.
 *
 * This program and the accompanying materials are dual-licensed under
 * either the terms of the Eclipse Public License v1.0 as published by
 * the Eclipse Foundation
 *
 *   or (per the licensee's choosing)
 *
 * under the terms of the GNU Lesser General Public License version 2.1
 * as published by the Free Software Foundation.
 */
package org.apache.juli.logging.ch.qos.logback.core.joran;

import org.apache.juli.logging.ch.qos.logback.core.CoreConstants;

/**
 *
 * This class contains constants used by Joran components.
 * 
 * @author Ceki G&uuml;lc&uuml;
 *
 */
public abstract class JoranConstants {
    public static final String INCLUDED_TAG = "included";
    public static final String CONFIGURATION_TAG = "configuration";

    public static final String INCLUDE_TAG = "include";

    public static final String APPENDER_TAG = "appender";
    public static final String REF_ATTRIBUTE = "ref";
    public static final String ADDITIVITY_ATTRIBUTE = "additivity";
    public static final String LEVEL_ATTRIBUTE = "level";
    public static final String CONVERTER_CLASS_ATTRIBUTE = "converterClass";
    public static final String CONVERSION_WORD_ATTRIBUTE = "conversionWord";
    public static final String PATTERN_ATTRIBUTE = "pattern";
    public static final String VALUE_ATTR = "value";
    public static final String ACTION_CLASS_ATTRIBUTE = "actionClass";

    public static final String INHERITED = "INHERITED";
    // all usages in the project are case-insensitive. Elsewhere this might not be the case hence the toUpperCase call
    public static final String NULL = CoreConstants.NULL_STR.toUpperCase();
    static final Class<?>[] ONE_STRING_PARAM = new Class[] { String.class };

    public static final String APPENDER_BAG = "APPENDER_BAG";
    public static final String APPENDER_REF_BAG = "APPENDER_REF_BAG";
    // public static final String FILTER_CHAIN_BAG = "FILTER_CHAIN_BAG";
}
